@@ -7,12 +7,11 @@ from os import path
 
 def json_parameters_function():
     def inner(func):
-        def wrapper(message):
-            o = JsonObject.load(message.body)
+        def wrapper(json_object):
             p = {}
             for v in func.__code__.co_varnames:
-                if v in o.__dict__:
-                    p[v] = o.__dict__[v]
+                if v in json_object.__dict__:
+                    p[v] = json_object.__dict__[v]
                 else:
                     p[v] = None
             func(**p)
